#!/bin/bash

MIRROR_SERVER="http://mirror.vitalinux.educa.aragon.es"

function create_source_list() {
    local _SRV=$1
    local proxy_file="/etc/apt/apt.conf.d/01cache_proxy"
    . /etc/default/vx-dga-variables/vx-dga-variables-general.conf
    #Comprobamos lo primero si el servidor caché está en la red
    if [ "$IPCACHE" != "" ] && nc -z "$IPCACHE" 3142 -w5 >/dev/null 2>&1; then
        echo "--> Servidor Cache que ofrece servicio APT-CACHER ..."
        echo "--> Se va a configurar al Servidor Cache como servidor APT-CACHER de software ..."

        echo "# Mod por migasfree-launcher: Hay conexión con el servidor APT-CACHER $IPCACHE" >/etc/apt/sources.list

        #Configuramos apt-proxy
        echo "Acquire::http { Proxy \"http://$IPCACHE:3142\"; };" >$proxy_file
        echo 'Acquire::https { Proxy "false"; };' >>$proxy_file
    else
        echo "# Mod por migasfree-launcher: NO hay conexión con algun servidor Caché" >/etc/apt/sources.list
        # Borrar el posible archivo generado anteriormente del proxy-cache
        if test -f $proxy_file; then
            rm -f $proxy_file
        fi
    fi
    # Crearmos las lineas del mirror
    cat >>/etc/apt/sources.list <<EOF
# Ubuntu Base Respositorios
deb ${_SRV}/ubuntu bionic main restricted universe multiverse
deb ${_SRV}/ubuntu bionic-updates main restricted universe multiverse
deb ${_SRV}/ubuntu bionic-security main restricted multiverse universe
deb ${_SRV}/ubuntu bionic-backports main restricted multiverse universe

# Libre Office 7.3
deb ${_SRV}/libreoffice-7-3 bionic main

# Chrome. Solo para 64 bits
deb [arch=amd64] ${_SRV}/google stable main

# Partners Ubuntu
deb ${_SRV}/canonical-partner bionic partner

# OpenJDK
deb ${_SRV}/openjdk-r bionic main

# Gimp 210 PPA
deb ${_SRV}/gimp210 bionic main

# Musescore3 PPA
deb ${_SRV}/musescore3 bionic main

# Shutter PPA
deb ${_SRV}/shutter bionic main

# Freecad PPA
deb ${_SRV}/freecad bionic main

# Openshot Developers 3.x
deb ${_SRV}/openshot-developers bionic main

EOF
}

# Función para revisar e instalar claves. Primer parámetro es la clave y segundo el servidor de claves
function install_apt_key() {
    # Ahora el ID de la clave son los 4 grupos de 4 de la huella larga....
    # Para descargarla, solo deberemos quitar los espacios de la huella para buscarla en el server
    if ! (apt-key list | grep "${1}") >/dev/null 2>&1; then
        echo "Clave ${3} no encontrada...Instalando"
        KEY=${1// /}
        apt-key adv --keyserver "${2}" --recv-keys "${KEY}"
        return $?
    fi
}

function searchkey_local_install() {
    # Por rapidez, podemos darle instalar la clave si tenemos la misma sin recurir al server de keys
    ## Ventajas: rapidez
    ## Desventaja: si cambia la clave, hay que actualizar la función
    # La podemos extraer de un equipo que ya la tenga con: apt-key export "089EBE08314DF160"
    if ! (apt-key list | grep "${1}") >/dev/null 2>&1; then
        KEY=${1// /}
        ${KEY} | apt-key add - >/dev/null 2>&1
    fi
}
function EA8CACC073C3DB2A() {
    echo '-----BEGIN PGP PUBLIC KEY BLOCK-----
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=Hd0U
-----END PGP PUBLIC KEY BLOCK-----
    '
}
function 3BDAAC08614C4B38() {
    echo '-----BEGIN PGP PUBLIC KEY BLOCK-----

mI0ES3pREAEEANqbN/8njQThILTmkmcRwycvAk25c7lNHxvYnmdNvcuFVMYN4oET
biZIBM0UuUcXF+6okmhvwf/XFNLWHDcFcozzEN9hvDuJIeSSImIeaGkrvGqQeEaS
dt+gC4cmm8499s4bGXvwX/KzC2U58FPFmNsMTQD4iVi7hju4hhfsrQ97ABEBAAG0
E0xhdW5jaHBhZCBvdHRvMDYyMTeItgQTAQIAIAUCS3pREAIbAwYLCQgHAwIEFQII
AwQWAgMBAh4BAheAAAoJEDvarAhhTEs4Rj4D/0xEqBsaaIPjTVopB+wg47zikvof
RuuTOOhC9H+x4qmS+NQttYbjf56pKREqCxMrt0ptaiuv6mkpNEPnr4tBVEsfNZKT
BdtkIUAvoBC/DsjaVtsjK0TKPX8BhtM+2J2IhToQ6AdFv3kM7EXBMTgxFGHrv796
aOeQzloOMzje+ijFiQEcBBABAgAGBQJTtSMgAAoJECA9PDILJjusGsQH/iWStp8M
rp7RWrQCeIlUvpf3BiDjvhb3c6/Yt8qFeGG/6u8UfHO1IHXHNcOhFxWE1m6UgaeZ
/jGFn8IxB0RmEKq4gqqRauZs3RlnfUX9JT1rAt6A2OwcxqBkjFIyFzGChhIt/HK9
jzB/bpQ6WX0s9NImJ8Ms5nUOrZU2XOzwQjfbi13XfJaAH7vpgrDXiyTfozwvJC5f
vkOgkx3VLge6PplAHbmwHRzFYFfi5kMxUPe33Z25zoKo8b6petL0GHex8GPsGcFl
wCWkRWV71Zmzix3lJ1cv7uc4IuvMRqSZkpbUFyh15vbEjA+2LeHXPVwcHj/DGFvh
48AuQBfUtDoRew8=
=+7P0
    -----END PGP PUBLIC KEY BLOCK-----'
}
function 04E482780EC0BBD2() {
    echo '-----BEGIN PGP PUBLIC KEY BLOCK-----

mI0ESXhUyQEEAK81+sxhhYvf5rjwnT+4FMkg+Gfc36r0DoT2+OtPcASK7Y+z3Xr/
ACzxQxrr5joyP6lpvIG9jClZ4zCuOi83odcKKq2xmwMCne+FBCAeHpPqWtWIrbY7
UxVw8M1Rmq0F6c79RQQf08ZVUK4qP9n12XRK2Peg93ME25Hxa5lL3GuvABEBAAG0
J0xhdW5jaHBhZCBQUEEgZm9yIE11c2VTY29yZSBNYWludGFpbmVyc4i2BBMBAgAg
BQJJeFTJAhsDBgsJCAcDAgQVAggDBBYCAwECHgECF4AACgkQBOSCeA7Au9KeQwP/
chCH0/kMcVmyhlLHU60pzdcAbTVGqWNsrmWDCq6I9dK/OxGKqoXd5injHD9/v5di
gBP6hKQuofL0Zhfk3wDcp930hoUTh2Gg1JSYqoowcGkzbsITN6tN3mxuweFlMK4v
3P/l9ji5rej2ptteB8wKD2S62S4fdiyZh13f5bWZwMw=
=yH0/
-----END PGP PUBLIC KEY BLOCK-----
    '
}
function 089EBE08314DF160() {
    echo '-----BEGIN PGP PUBLIC KEY BLOCK-----

mI0ESgc8TwEEANnh7UAVSnJoE8fyLMss5VUuG+1Bw5W2XWEyxuOCfMMAnJq4FY7Y
OjaFwX37KdPTy5/+NVqegazUbB3WV8d21aRhN977HXYztt/1Ft73m30FLbZC3vRw
aMg5oaWQ/XAy9ONY8QND/ahhSNf3d8wyrfAlG2RLaUeASDXqMBOU2fKVABEBAAG0
GkxhdW5jaHBhZCB1YnVudHVnaXMtc3RhYmxliLYEEwECACAFAkoHPE8CGwMGCwkI
BwMCBBUCCAMEFgIDAQIeAQIXgAAKCRAInr4IMU3xYG3iA/0dnVOYqpLayEgzmlJ6
mwJnVKcL+tGRfNsKQTHe77skFBcO/YyLez29HJJJS0xGtkZ+bUEQ3mdKnV/jGK4y
geSouItfz3fM3/PvVbZMbARUTzOdIR/Hv8GUyVhY3dPR8NEyw0Op41kCOuxZBVU9
85IQHDDQe6Fw1q6IFjOES0NMjQ==
=gZdQ
-----END PGP PUBLIC KEY BLOCK-----
    '
}
function 005EAE8119BB5BCA() {
    echo '-----BEGIN PGP PUBLIC KEY BLOCK-----

mI0ETYF+BAEEAK1n4CPNzdG/rTNvteUkHOiSikl07GJl7jh8RjL4T2BA3g2J0M0g
x20gOfc2Srbmg676cdf2kIzhfVPbjvWJnDYsFS1BOa0ZsKb0xN6lZzMU2lhmPMgF
jJJk94BqeLlxr9wSqmOkR8X3yDtNWbZ+5xO1wDUP4GDZcCwesVsWfdXZABEBAAG0
JUxhdW5jaHBhZCBQUEEgZm9yIEZyZWVDQUQgbWFpbnRhaW5lcnOIuAQTAQIAIgUC
TYF+BAIbAwYLCQgHAwIGFQgCCQoLBBYCAwECHgECF4AACgkQAF6ugRm7W8oktwP+
Nzk9OEg3kl8fNd9JeTWrw2UnisfPOIV7HTATpLqnXZQOQ+Q7QjsRL6yRMj+U6OWa
9pgDrljJyg77DFCcHipCrR5LiXdxzzK2Z2wbStxsS2U3v7HJaXw4gmYAGyahswLa
RzbmV95JXeFAGjXM5yH6FTxbzGdH/IaXN1ASMMZQedU=
=3tnf
-----END PGP PUBLIC KEY BLOCK-----
    '
}
function 8A993C2521C5F0BA() {
    echo '-----BEGIN PGP PUBLIC KEY BLOCK-----

mQINBFRuX8IBEADRAN5+JtzhrVIM2pe48sinBwwU/NlCbfZo3RJeGXOl0AmClbUZ
2wWl9/FFdxmodJ4u+VRxPBMxSrBhj9Lp1ZvyTjgg77uDFtnFE7GyP5GYsuRi5YU+
HhxY0iHg+QjL5EYHB168Z9KfZeNcOvop8lVRL8bEfVfw7H72Vy4C9/YSCdPFvWNE
TulkLyTGBzXmH5TkqL7txP/qlp+f3IX8OVSJpF0skEZNMvxPHuTI5qwOyBT0pPPO
649vdVezfr6EbegbMHxR5zljfUHx70ta4Y2BHG5IrU/x103R/uoJqX1X7B/FNPoh
lkKpsgD5h8ccLWNvSxfIHdN9hX+qYGYP8ByPzW+erwW6IoQZWR6Sr0Tk30i+8i6/
4WNUQ7OGAhNApAR1SJQO750fBF86P75zNwMt8W/LXqrmj/+Ub+UDG7JfQV1zfUA/
6CB5XVPbsv3T+Fv0xTxqJ+FdaCTF+2PFCc7UetTnXZXzl4kjPkEmTO4Kk2+g+NNb
HoZ40AHD7772+J5seiqSY6UxjTRtui55XAexRFuLQeeXs+gTkxkH1JerjU+Q/W1z
4HCYZ/kXtk5sucfs96r+7UI5Os3TBTt12cJAnyb0WgZpDtatEnhbblS26KRcOVs6
TxQy2rG2LCfxkC+T3vAzMc04McNYeAJCScv641+2nEZzw5HtgUDosqPTLwARAQAB
tCJMYXVuY2hwYWQgUFBBIGZvciBSZW1taW5hIFBQQSBUZWFtiQI4BBMBAgAiBQJU
bl/CAhsDBgsJCAcDAgYVCAIJCgsEFgIDAQIeAQIXgAAKCRCKmTwlIcXwulEvEACc
9oqQGhrFFNjMyYOdMMVH+0QYD0yeiAKdkiFi0izxEBx7bF+Vc3wdypSDlzmitYsN
/Xn1MmAxTXLC8kq+awtuh+mnoXlaJMmxK5yVjLUqVIWqT8hG5TDYmgF1ckNCK1ek
fVpMBM2tpDccXPriMvKZ5dyfVJ2GBAyaywsNu8F48BbUV8DyZThSY5H4zlGnPKcg
vbB2YFeAKgW2khPwn2zkVvgfOIW9hj+0HVfelf7hbKy/b8oIGQaj5Qg8d6ipdL8H
9fkA3RV77BsFq15NgEgHQF0O3UyxVyfRc42EozV8e7nXXKdWstq+Z/swVLB0hE0h
r5T6oRRrK4oypGpWd8ASkyIj51uakRBw3GYTgB3UL6jPTZO0BZ+YYvRmV0hyCu8E
39a2GrJJ+AQFL4ER9WB6ZKAQn2JsgxITDlz25VEbrqfY51oCBL7dMc5rgaXSXLbi
VwWZ89Lp4EhbfLXJfc+jWiIu08SOYBNC1qWSmBlMwQg4ItSiqTbfMFDOQu7VmBa2
S12g/aK1DgteeNQJ7o/Rwiu9C46RgfHVRoy//nOrsSaX71MzzQgzpj197SqMfouq
jzw+KAZ+Zh+2a/9sTiPGdDtxvctdGXBSk+g8ZNcQa1kGd/JfMcYrjVHzcOaGgFMo
XQiCklI6JFDOf9Hp1FCA5AOhAFysU5ZUw5lq56C3xQ==
=QKRB
-----END PGP PUBLIC KEY BLOCK-----
    '
}
function 52165BD6B9BA26FA() {
    echo '-----BEGIN PGP PUBLIC KEY BLOCK-----
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=NHN7
-----END PGP PUBLIC KEY BLOCK-----
    '
}

echo "=> Seguimos con la creación del sources.list ...."

# Revisión e instalación de las claves necesarias:
# Libreoffice
install_apt_key "83FB A175 1378 B444" keyserver.ubuntu.com libreoffice
# openjdk-r
install_apt_key "EB9B 1D88 86F4 4E2A" keyserver.ubuntu.com openjdk

# Instalamos claves de ppas en mirror también, pero sin usar el server de claves (herencia de falla)
# Shutter
searchkey_local_install "EA8C ACC0 73C3 DB2A"
# Gimp210
searchkey_local_install "3BDA AC08 614C 4B38"
# Musescore
searchkey_local_install "04E4 8278 0EC0 BBD2"
# UbuntuQGis
searchkey_local_install "089E BE08 314D F160"
# Freecad
searchkey_local_install "005E AE81 19BB 5BCA"
## Remmina-next
searchkey_local_install "8A99 3C25 21C5 F0BA"
# Openshot 3
searchkey_local_install "5216 5BD6 B9BA 26FA"

# Chrome. No hace uso del servidores de claves, sino de uno propio
# Primero borraríamos si diera errores:
#(apt-key list | grep D38B4796)  > /dev/null 2>&1 && \
# echo "Borrando clave Google antigua D38B4796" && \
# apt-key del D38B4796 > /dev/null
## Ahora ha cambiado la clave, con mismo identificador ya que es subclave
if ! (apt-key list --fingerprint | grep -q "4EB2 7DB2 A3B8 8B8B") >/dev/null 2>&1; then
    echo "Clave Google no encontrada...Instalando"
    wget -q -O - https://dl.google.com/linux/linux_signing_key.pub | apt-key add - >/dev/null
fi

# Limpiar los sources que existan antiguos
# Libreoffice
find /etc/apt/sources.list.d/ -regextype posix-egrep -regex '.*libreoffice.*list$' -exec mv '{}' '{}'.save \;
# Chrome
find /etc/apt/sources.list.d/ -regextype posix-egrep -regex '.*chrome.*list$' -exec mv '{}' '{}'.save \;
# openjdk-r
find /etc/apt/sources.list.d/ -regextype posix-egrep -regex '.*openjdk-r.*list$' -exec mv '{}' '{}'.save \;
# getdeb
find /etc/apt/sources.list.d/ -regextype posix-egrep -regex '.*getdeb.*list$' -exec mv '{}' '{}'.save \;
# gimp
find /etc/apt/sources.list.d/ -regextype posix-egrep -regex '.*gimp.*list$' -exec mv '{}' '{}'.save \;
# musescore
find /etc/apt/sources.list.d/ -regextype posix-egrep -regex '.*musescore.*list$' -exec mv '{}' '{}'.save \;
# shutter
find /etc/apt/sources.list.d/ -regextype posix-egrep -regex '.*shutter.*list$' -exec mv '{}' '{}'.save \;
# freecad
find /etc/apt/sources.list.d/ -regextype posix-egrep -regex '.*freecad.*list$' -exec mv '{}' '{}'.save \;
# Canonical?
find /etc/apt/sources.list.d/ -regextype posix-egrep -regex '.*canonical.*list$' -exec mv '{}' '{}'.save \;
# Geogebra
find /etc/apt/sources.list.d/ -regextype posix-egrep -regex '.*geogebra.*list$' -exec mv '{}' '{}'.save \;

# Creamos el sources.list
create_source_list $MIRROR_SERVER
